function F = Lotka_Volterra(t,X,a,b,c,d)

% Returns vector field for Lotka-Volterra ODE system (F)
% X = [x;y] - vector storing dependent variables as components
% x = prey 
% y = predator
% F = [dx_dt;dy_dt] - returning a vector (1st component = dx_dt, 2nd component = dy_dt)
% a,b,c,d - parameters (>0)
    % a = prey (x) growth rate (exponential)
    % b = prey (x) death rate due to interactions with predator (y)
    % c = predator (y) growth rate due to consuming prey (x)
    % d = predator (y) death rate (exponential)
% Note: must include t for ode solver (ode45)
% Lotka_Volterra.m must be the name of the file (what is called by other programs), F is variable that is returned whenever Lotka_Volterra is called
    
% Unpack X into x and y components (easier to understand, i.e. less likely to have errors in code)
x = X(1);
y = X(2);

% Now write vector field
dx_dt = a*x - b*x*y;
dy_dt = c*x*y - d*y;

% Combine for output
F = [dx_dt;dy_dt];

end